==> AMR_0.4.0.tar.gz: AMR/inst/doc/freq.R <==
## ----setup, include = FALSE, results = 'markup'--------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#"
)
library(dplyr)
library(AMR)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>% freq(gender)

## ---- echo = TRUE, results = 'hide'--------------------------------------
my_patients <- septic_patients %>% left_join_microorganisms()

## ---- echo = TRUE--------------------------------------------------------
colnames(microorganisms)

## ---- echo = TRUE--------------------------------------------------------
dim(septic_patients)
dim(my_patients)

## ---- echo = TRUE--------------------------------------------------------
my_patients %>% freq(genus, species)

## ---- echo = TRUE--------------------------------------------------------
# # get age distribution of unique patients
septic_patients %>% 
  distinct(patient_id, .keep_all = TRUE) %>% 
  freq(age, nmax = 5)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, sort.count = TRUE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  select(amox) %>% 
  freq()

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  select(date) %>% 
  freq(nmax = 5)

## ---- echo = TRUE--------------------------------------------------------
my_df <- septic_patients %>% freq(age)
class(my_df)

## ---- echo = TRUE--------------------------------------------------------
dim(my_df)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(amox, na.rm = FALSE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, row.names = FALSE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, markdown = TRUE)

## ---- echo = FALSE-------------------------------------------------------
# this will print "2018" in 2018, and "2018-yyyy" after 2018.
yrs <- paste(unique(c(2018, format(Sys.Date(), "%Y"))), collapse = "-")

==> AMR_0.6.1.tar.gz: AMR/inst/doc/freq.R <==
## ----setup, include = FALSE, results = 'asis'----------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#",
  results = 'asis',
  fig.width = 7.5,
  fig.height = 4.5
)
library(dplyr)
library(AMR)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>% freq(gender)

## ---- echo = TRUE, results = 'hide'--------------------------------------
my_patients <- septic_patients %>% left_join_microorganisms()

## ---- echo = TRUE, results = 'markup'------------------------------------
colnames(microorganisms)

## ---- echo = TRUE, results = 'markup'------------------------------------
dim(septic_patients)
dim(my_patients)

## ---- echo = TRUE--------------------------------------------------------
my_patients %>%
  freq(genus, species, nmax = 15)

## ---- echo = TRUE--------------------------------------------------------
# # get age distribution of unique patients
septic_patients %>% 
  distinct(patient_id, .keep_all = TRUE) %>% 
  freq(age, nmax = 5, header = TRUE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, sort.count = FALSE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(amox, header = TRUE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(date, nmax = 5, header = TRUE)

## ---- echo = TRUE--------------------------------------------------------
my_df <- septic_patients %>% freq(age)
class(my_df)

## ---- echo = TRUE--------------------------------------------------------
dim(my_df)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(amox, na.rm = FALSE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, row.names = FALSE)

## ---- echo = TRUE--------------------------------------------------------
septic_patients %>%
  freq(hospital_id, markdown = TRUE)
